<?php

namespace Drupal\points\Access;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Entity\EntityAccessControlHandler;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Access controller for the Point entity.
 *
 * @see \Drupal\points\Entity\Point.
 */
class PointAccessControlHandler extends EntityAccessControlHandler {

  /**
   * {@inheritdoc}
   */
  protected function checkAccess(EntityInterface $entity, $operation, AccountInterface $account) {
    if ($account->hasPermission('administer point entities')) {
      return AccessResult::allowed();
    }

    /** @var \Drupal\points\Entity\PointInterface $entity */
    switch ($operation) {
      case 'view':
        return AccessResult::allowedIfHasPermission($account, 'view point entities');

      case 'update':
        return AccessResult::allowedIfHasPermission($account, 'edit point entities');

      case 'delete':
        return AccessResult::allowedIfHasPermission($account, 'delete point entities');

    }

    return AccessResult::neutral();
  }

  /**
   * {@inheritdoc}
   */
  protected function checkCreateAccess(AccountInterface $account, array $context, $entity_bundle = NULL) {
    $permissions = [
      'administer point entities',
      'create point entities',
    ];
    return AccessResult::allowedIfHasPermissions($account, $permissions, 'OR');
  }

}
